Struct KeyValues
Source pub struct KeyValues<'a>();
A collection of key-value pairs.
Get the number of key-value pairs.
Check if there are no key-value pairs.
Get an iterator over the key-value pairs.
Get the value for a given key.
If the key appears multiple times in the source then which key is returned is undetermined.
Visit the key-value pairs with the provided visitor.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Converts to this type from the input type.
Converts to this type from the input type.
The type of the elements being iterated over.
Which kind of iterator are we turning this into?
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Attaches the provided
Context to this type, returning a
WithContext
wrapper.
Read more
Attaches the current
Context to this type, returning a
WithContext
wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.