pub struct EnvFilter { /* private fields */ }Expand description
A filter consists of one or more comma-separated directives which match on Record.
Each directive may have a corresponding maximum verbosity Level which enables
records that match.
Less exclusive levels (like trace or info) are considered to be more verbose than more
exclusive levels (like error or warn).
Read more from the module level documentation about the directive syntax and use cases.